/*
  stepper.h - a simple library for driving a stepper motor attached to an L293D via an 8-bit shift register
  Written by Rylee Isitt
*/
#ifndef stepper_H
#define stepper_H

#include <Arduino.h>
#include "shiftRegister8.h"

class stepper
{
public:
    stepper(shiftRegister8 *shiftRegister, byte maskEnableA, byte maskEnableB, byte maskA1, byte maskA2, byte maskB1, byte maskB2);
    ~stepper(void);
    void enable(void);
    void disable(void);
    void brake(void);
    void step(boolean forward);
    void seek(long goalPos);
    void start(boolean forward);
    void stop(void);
    void update(void);
    boolean isMoving;
    long pos; // current position in half steps
    long goalPos;
    boolean reverseMotor;
    boolean halfMode; // if true, motor will use half steps, otherwise will use full steps
    boolean accelerate;
    unsigned int maxRPM;
    unsigned int curRPM;
    unsigned int stepsPerRev;
private:
    shiftRegister8 * shiftRegister;
    byte stepperStageBitMask;
    byte maskEnableA;
    byte maskEnableB;
    byte maskA1;
    byte maskA2;
    byte maskB1;
    byte maskB2;
    unsigned int accelHalfSteps;
};

#endif
